import re

color_regex = '#[0-9A-F]{6}'

plot_types = {
        'linesDots': {
            "description": (
                "Lines, one color dots. Dot or line/color mapping defined by "
                "ValueColors.\n"
                "Ex: Line:#00FF00|Dot:#FF0000  means\n"
                "   Lines are plotted with color #00FF00\n"
                "   Dots are plotted with color #FF0000\n"
                "If Dot is not defined, dots won't be displayed.\n"
                "If L is not defined, lines will be plotted with color "
                "#00FF00.\n"
                "Optionally, a color for points with value 0 can be defined "
                "This is currently only used for channel GPS Lk/Unlk.\n"
                "Ex: Zero:#0000FF means points with value are plotted with "
                "color #0000FF."
            ),
            "plot_function": "plot_lines_dots",
            "value_pattern": re.compile('^(L|D|Z|Line|Dot|Zero)$'),
            "pattern": re.compile(f'^(?:Line|Dot|Zero):{color_regex}$'),
            "instruction": (
                "Ex: Line:#00FF00|Dot:#FF0000  means\n"
                "   Lines are plotted with color #00FF00\n"
                "   Dots are plotted with color #FF0000\n"
                "If Dot is not defined, dots won't be displayed.\n"
                "If L is not defined, lines will be plotted with color "
                "#00FF00.\n"
                "Optionally, a color for points with value 0 can be defined "
                "This is currently only used for channel GPS Lk/Unlk.\n"
                "Ex: Zero:#0000FF means points with value are plotted with "
                "color #0000FF."
            ),
            "default_value_color": "Line:#00FF00"
        },
        'linesSRate': {
            "description": "Lines, one color dots, bitweight info. ",
            "plot_function": "plot_lines_s_rate"
        },
        'linesMasspos': {
            "description": "multi-line mass position, multi-color dots. ",
            "plot_function": "plot_lines_mass_pos"
        },
        'triColorLines': {
            "description": "Three lines with three different colors for "
                           "values -1, 0, 1.",
            "plot_function": "plot_tri_colors",
            "value_pattern": re.compile('^-?[10]?$'),
            "pattern": re.compile(f'^-?[10]:{color_regex}$'),
            "default_value_color": "-1:#FF0000|0:#00FF00|1:#0000FF"
        },
        'dotForTime': {
            "description": (
                "Dots according to timestamp.\n"
                "Color defined by ValueColors.\n"
                "Ex: Color:#00FF00"),
            "plot_function": "plot_dot_for_time",
            "value_pattern": re.compile('^C|(Color)$'),
            "pattern": re.compile(f'^Color:{color_regex}$'),
            "default_value_color": "Color:#00FF00"
        },
        'multiColorDotsEqualOnUpperBound': {
            "description": (
                "Multicolor dots in center with value/colors mapping defined "
                "by ValueColors.\n"
                "Ex: <=-1:not plot|<=0:#FF0000|0<:#FF00FF  means:\n"
                "   value <= -1   => not plot\n"
                "   -1 < value <= 0 => plot with #FF0000 color\n"
                "   0 < value  => plot with #FF00FF color\n"
            ),
            "plot_function": "plot_multi_color_dots_equal_on_upper_bound",
            "value_pattern": re.compile(r'^(\+|<=)?[0-9]+\.?[0-9]?<?$'),
            "pattern": re.compile(
                fr'^(\+|<=)?[0-9]+\.?[0-9]?<?:(?:{color_regex}|not plot)$'
            ),
            "instruction": (
                "Ex: <=-1:not plot|<=0:#FF0000|0<:#FF00FF  means:\n"
                "   value <= -1   => not plot\n"
                "   -1 < value <= 0 => plot with #FF0000 color\n"
                "   0 < value  => plot with #FF00FF color\n"
            ),
            "default_value_color": "<=0:#FF0000|0<:#FF00FF"
        },
        'multiColorDotsEqualOnLowerBound': {
            "description": (
                "Multicolor dots in center with value/colors mapping defined "
                "by ValueColors.\n"
                "Ex: <-1:not plot|<0:#FF0000|=0:#FF00FF  means:\n"
                "   value < -1   => not plot\n"
                "   -1 =< value < 0 => plot with #FF0000 color\n"
                "   value >= 0  => plot with #FF00FF color\n"
            ),
            "plot_function": "plot_multi_color_dots_equal_on_lower_bound",
            "value_pattern": re.compile(r'^[=<]?[0-9]\.?[0-9]?$'),
            "pattern": re.compile(
                fr'^[=<]?[0-9]\.?[0-9]?:(?:{color_regex}|not plot)'
            ),
            "instruction": (
                "Ex: <-1:not plot|<0:#FF0000|=0:#FF00FF  means:\n"
                "   value < -1   => not plot\n"
                "   -1 =< value < 0 => plot with #FF0000 color\n"
                "   value >= 0  => plot with #FF00FF color\n"
            ),
            "default_value_color": "<0:#FF0000|=0:#00FF00"
        },
        'upDownDots': {
            "description": (
                "Show data with 2 different values: first down/ second up. "
                "Colors defined by ValueColors.\nEx: Down:#FF0000|Up:#00FFFF"),
            "plot_function": 'plot_up_down_dots',
            "value_pattern": re.compile("^(0|1|Up|Down)$"),
            "pattern": re.compile(f"^(?:Up|Down):{color_regex}$"),
            "instruction": (
                "Colors looks like #12ABEF\n"
                "Ex: Down:#FF0000|Up:#00FFFF  means:\n"
                "   value == 1 => plot above center line with #00FFFF color\n"
                "   value == 0 => plot under center line with #FF0000 color"),
            "default_value_color": "Down:#FF0000|Up:#00FFFF"
        }
    }
